--[[
**************************************************************************
*     Module d'exportation des infos de performance LockOn 2.00          *
*     Par KaTZe     -         http://www.3rd-wing.net                    *
*     Version 2.0.1  du   01/09/2010                                     *
*     															         *
*     Ce module cr un fichier "sparateur ;' pour enregister           *
*     Temps, TAS, QNH, distance	...							       		 *
**************************************************************************
--]]

DEBUG_MODE = true; 	-- fichier ..\Lock On\Temp\KTZ-DataCollect.log

-- logData("---KaTZe Log: KTZ-Data-Collect Activated ----")

-- Corps du programme d'export

StartTime = LoGetMissionStartTime()
CurrentTime = LoGetModelTime()
SamplingPeriod = 1
NextSampleTime = CurrentTime + SamplingPeriod
	


KTZ_FPS =
{

-- Fonction au dmarrage mission
	K_Start=function(self)
	
	logData("Temps;IAS;TAS;QNH;Variometre;AoA;Distance;Rpm_Left;Rpm_Right;Fuel;Consommation")	
	end,


-- Fonction  chaque image
	K_AfterNextFrame=function(self)
		CurrentTime = LoGetModelTime()
	end,

	
-- Fonction  chaque intervalle de temps
	K_AtInterval=function(self)
			
		local engine = LoGetEngineInfo()
		local Fuel_last = engine.fuel_internal + engine.fuel_external
		local Fuel_conso = (engine.FuelConsumption.left + engine.FuelConsumption.right)*6
		local IAS = LoGetIndicatedAirSpeed() * 3.6
		local TAS = LoGetTrueAirSpeed() * 3.6
		local QNH = LoGetAltitudeAboveSeaLevel()
		local AoA = LoGetAngleOfAttack()*57.32  -- LO200 valeur en rad , convertie en degr
		local Vario = LoGetVerticalVelocity()
		
		local myXCoord, myZCoord
		if LoGetPlayerPlaneId() then
			local objPlayer = LoGetObjectById(LoGetPlayerPlaneId())
			myXCoord, myZCoord = getXYCoords(objPlayer.LatLongAlt.Lat, objPlayer.LatLongAlt.Long)
			--logData(string.format(%.6f;%.6f,myXCoord, myZCoord))
		end
		
		local _LoGetRoute = LoGetRoute()
		local distance = math.sqrt(math.pow(_LoGetRoute.goto_point.world_point.x-myXCoord,2)+math.pow(_LoGetRoute.goto_point.world_point.z-myZCoord,2))
				
		if distance == nil then
			distance = 9999
		end 
		
		--	Log des donnes:		
		logData(string.format("%.1f;%.0f;%.0f;%.0f;%.1f;%.1f;%.0f;%.0f;%.0f;%0.f;%0.1f",CurrentTime,IAS,TAS,QNH,Vario,AoA,distance,engine.RPM.left,engine.RPM.right,Fuel_last,Fuel_conso))
		
		-- calcul de la date de fin du prochain intervalle de temps
		NextSampleTime = CurrentTime + SamplingPeriod

	end,

	
	
-- Fonction fin de mission
	K_Stop=function(self)
	
		
	end,

}

	------------------------------------------------------------------------
	--    Fonction pour le calcul des coordonnes rcupr dans LOVP     --
	--	  Merci  Mnemonic                           					  --
	------------------------------------------------------------------------
	getXYCoords = function(inLatitudeDegrees, inLongitudeDegrees) -- args: 2 numbers // Return two value in order: X, Y
        local pi = 3.141592

		local zeroX = 5000000
		local zeroZ = 6600000

		local centerX = 11465000 - zeroX --circle center
		local centerZ =  6500000 - zeroZ

		local pnSxW_X = 4468608 - zeroX -- point 40dgN : 24dgE
		local pnSxW_Z = 5730893 - zeroZ

		local pnNxW_X = 5357858 - zeroX -- point 48dgN : 24dgE
		local pnNxW_Z = 5828649 - zeroZ

		local pnSxE_X = 4468608 - zeroX -- point 40dgN : 42dgE
		local pnSxE_Z = 7269106 - zeroZ

		local pnNxE_X = 5357858 - zeroX -- point 48dgN : 42dgE
		local pnNxE_Z = 7171350 - zeroZ

		local lenNorth = math.sqrt((pnNxW_X-centerX)*(pnNxW_X-centerX) + (pnNxW_Z-centerZ)*(pnNxW_Z-centerZ))
		local lenSouth = math.sqrt((pnSxW_X-centerX)*(pnSxW_X-centerX) + (pnSxW_Z-centerZ)*(pnSxW_Z-centerZ))
		local lenN_S = lenSouth - lenNorth

		local RealAngleMaxLongitude = math.atan ((pnSxW_Z - centerZ)/(pnSxW_X - centerX)) * 180/pi
		-- borders
		local EndWest = 24
		local EndEast = 42
		local EndNorth = 48
		local EndSouth = 40
		local MiddleLongitude = (EndWest + EndEast) / 2
		local ToLengthN_S = ((EndNorth - EndSouth) / lenN_S)
		local ToAngleW_E = (MiddleLongitude - EndWest) / RealAngleMaxLongitude

		local ToDegree = 360/(2*pi)
	    -- Lo coordinates system
	    local realAng = (inLongitudeDegrees - MiddleLongitude) / ToAngleW_E / ToDegree;
	    local realLen = lenSouth - (inLatitudeDegrees - EndSouth) / ToLengthN_S;
	    local outX = centerX - realLen * math.cos (realAng);
	    local outZ = centerZ + realLen * math.sin (realAng);
	    return outX, outZ
	end	


-- Declencheur de squence (depuis export.lua)
------------------------------------------------------------------------
--    Squence : Dmarrage de mission (ExportStart)    			  --
------------------------------------------------------------------------

do
	local PrevLuaExportStart=LuaExportStart;

	LuaExportStart=function()
		KTZ_FPS:K_Start();
		
		if PrevLuaExportStart then
			PrevLuaExportStart();
		end
	end
end


------------------------------------------------------------------------
--    Squence : a chaque image            							  --
------------------------------------------------------------------------

do
	local PrevLuaExportAfterNextFrame=LuaExportAfterNextFrame;

	LuaExportAfterNextFrame=function()
		KTZ_FPS:K_AfterNextFrame();
			if CurrentTime >= NextSampleTime then
				KTZ_FPS:K_AtInterval();
			end
			
		if PrevLuaExportAfterNextFrame then
			PrevLuaExportAfterNextFrame();
		end
	end
end


------------------------------------------------------------------------
--    Squence : Fin de mission (ExportStop)         				  --
------------------------------------------------------------------------

do
	local PrevLuaExportStop=LuaExportStop;

	LuaExportStop=function()
		KTZ_FPS:K_Stop();

		if PrevLuaExportStop then
			PrevLuaExportStop();
		end
	end
end

------------------------------------------------------------------------
--    Fonction logData												  --
------------------------------------------------------------------------
function logData(message)
	if DEBUG_MODE and not fichierDataLog then
       	fichierDataLog = io.open("./Temp/KTZ-LO200_DataPerf-"..os.date("%Y%m%d-%H%M")..".csv", "w");
		if fichierDataLog then
			io.output(fichierDataLog);
			io.write("*********************************************;\n");
			io.write("*     Fichier Data Performance Log LO-201   *;\n");
			io.write("*     Par KaTZe  -  http://www.3rd-wing.net *;\n");
			io.write("*     Version 2.0.1 du 01/09/2010           *;\n");
			io.write("*********************************************;\n\n");
		end
    end
	if fichierDataLog then
        io.write(string.format(" %s ; %s",os.date("%d/%m/%y %H:%M:%S"),message),"\n");
	end
end